@@ -25,20 +25,19 @@ class DescribeCdnReportListRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'DescribeCdnReportList')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ReportId(self):
+	def get_ReportId(self): # Long
 		return self.get_query_params().get('ReportId')
 
-	def set_ReportId(self,ReportId):
-		self.add_query_param('ReportId',ReportId)
-
-	def get_OwnerId(self):
+	def set_ReportId(self, ReportId):  # Long
+		self.add_query_param('ReportId', ReportId)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
