@@ -25,44 +25,39 @@ class UpdateFCTriggerRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'UpdateFCTrigger')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Notes(self):
+	def get_Notes(self): # String
 		return self.get_body_params().get('Notes')
 
-	def set_Notes(self,Notes):
+	def set_Notes(self, Notes):  # String
 		self.add_body_params('Notes', Notes)
-
-	def get_TriggerARN(self):
+	def get_TriggerARN(self): # String
 		return self.get_query_params().get('TriggerARN')
 
-	def set_TriggerARN(self,TriggerARN):
-		self.add_query_param('TriggerARN',TriggerARN)
-
-	def get_SourceARN(self):
+	def set_TriggerARN(self, TriggerARN):  # String
+		self.add_query_param('TriggerARN', TriggerARN)
+	def get_SourceARN(self): # String
 		return self.get_body_params().get('SourceARN')
 
-	def set_SourceARN(self,SourceARN):
+	def set_SourceARN(self, SourceARN):  # String
 		self.add_body_params('SourceARN', SourceARN)
-
-	def get_OwnerId(self):
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_RoleARN(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_RoleARN(self): # String
 		return self.get_body_params().get('RoleARN')
 
-	def set_RoleARN(self,RoleARN):
+	def set_RoleARN(self, RoleARN):  # String
 		self.add_body_params('RoleARN', RoleARN)
-
-	def get_FunctionARN(self):
+	def get_FunctionARN(self): # String
 		return self.get_body_params().get('FunctionARN')
 
-	def set_FunctionARN(self,FunctionARN):
-		self.add_body_params('FunctionARN', FunctionARN)
\ No newline at end of file
+	def set_FunctionARN(self, FunctionARN):  # String
+		self.add_body_params('FunctionARN', FunctionARN)
